camelot_manage — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- bin »

# camelot_manage

camelot_manage is oriented towards administrators of an installed camelot application. It is used for interacting the database, the model and migration of the database to a certain schema revision.

To use this application, PYTHONPATH should contain a valid settings.py file that will be used to resolve the database engine and the model.

`console`

  Launches a python console with the model all setup for command line interaction.

  Within the example movie project one could do the following to print a list of all movie titles to the screen:

      from model import Movie
      for movie in Movie.query.all():
      print movie.title

`db_version`

  Get the version of the database schema from the current database

`version`

  Get the latest available database schema version

`upgrade`

  Upgrade or downgrade the database to the specified version, use upgrade version_number.

`version_control`

  Put the database under version control

`schema_display`

  > Generate a graph of the database schema. The result is stored in schema.png. This option requires pydot to be installed.

class `camelot.bin.camelot_manage.` `FileCacher`

  Cache the stdout text so we can analyze it before returning it

class `camelot.bin.camelot_manage.` `Shell`(locals={})

  Wrapper around Python that can filter input/output to the shell

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- bin »

Comments
blog comments powered by Disqus